==> arrow-docs-0.8.0-sources.jar: com/example/domain/HttpError$$optics.kt <==
package `com`.`example`.`domain`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `com`.`example`.`domain`.`HttpError`.Companion.iso: arrow.optics.Iso<`com`.`example`.`domain`.`HttpError`, `kotlin`.`String`> inline get()= arrow.optics.Iso(
  get = { httpError: `com`.`example`.`domain`.`HttpError` -> httpError.message },
  reverseGet = { `com`.`example`.`domain`.`HttpError`(it) }
)

inline val `com`.`example`.`domain`.`HttpError`.Companion.message: arrow.optics.Lens<`com`.`example`.`domain`.`HttpError`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { httpError: `com`.`example`.`domain`.`HttpError` -> httpError.`message` },
  set = { value: `kotlin`.`String` ->
    { httpError: `com`.`example`.`domain`.`HttpError` ->
      httpError.copy(`message` = value)
    }
  }
)



inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`HttpError`>.message: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`HttpError`.message
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`HttpError`>.message: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`HttpError`.message
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`HttpError`>.message: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`HttpError`.message
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`HttpError`>.message: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`HttpError`.message
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`HttpError`>.message: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`HttpError`.message
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`HttpError`>.message: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`HttpError`.message
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`HttpError`>.message: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`HttpError`.message
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`HttpError`>.message: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`HttpError`.message

==> arrow-docs-0.10.3-sources.jar: com/example/domain/HttpError$$optics.kt <==
package `com`.`example`.`domain`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `com`.`example`.`domain`.`HttpError`.Companion.iso: arrow.optics.Iso<`com`.`example`.`domain`.`HttpError`, `kotlin`.`String`> inline get()= arrow.optics.Iso(
  get = { httpError: `com`.`example`.`domain`.`HttpError` -> httpError.message },
  reverseGet = { `com`.`example`.`domain`.`HttpError`(it) }
)

inline val `com`.`example`.`domain`.`HttpError`.Companion.message: arrow.optics.Lens<`com`.`example`.`domain`.`HttpError`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { httpError: `com`.`example`.`domain`.`HttpError` -> httpError.`message` },
  set = { httpError: `com`.`example`.`domain`.`HttpError`, value: `kotlin`.`String` -> httpError.copy(`message` = value) }
)



inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`HttpError`>.message: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`HttpError`.message
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`HttpError`>.message: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`HttpError`.message
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`HttpError`>.message: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`HttpError`.message
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`HttpError`>.message: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`HttpError`.message
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`HttpError`>.message: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`HttpError`.message
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`HttpError`>.message: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`HttpError`.message
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`HttpError`>.message: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`HttpError`.message
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`HttpError`>.message: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`HttpError`.message
